pytilities.geometry.vector — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.vector

class `pytilities.geometry.vector.` `Vector`

  2D Point/Vector with coordinates in a continuous space (float).

  Note on Vector, DiscreteVector operations: Vector op DiscreteVector returns Vector. DiscreteVector op DiscreteVector returns DiscreteVector.

  `INFINITY`
  `NULL`
  `cross` = <pytilities.aop.functions._CallableWrapper object at 0x1d35a90>
  `dot` = <pytilities.aop.functions._CallableWrapper object at 0x1d35d10>
  `length`

    Read-write, length of vector

    Returns :: float | int

    Set parameters:

    > value :: number
    >   new length

  `length_squared`

    Read-only, length squared :: float | int

  `normalize` = <pytilities.aop.functions._CallableWrapper object at 0x1d35ed0>
  `normalized` = <pytilities.aop.functions._CallableWrapper object at 0x1d35f50>
  `reflect` = <pytilities.aop.functions._CallableWrapper object at 0x1d35fd0>

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »